Ryan Barrett
Where did you go to high school?
Edit Profile Picture
Edit Cover Photo
No longer here. Follow me on snarfed.org!
Edit Bio
Timeline · Friends · Following · View As · Activity Log
What city are you from?
Add work
Add college
Add graduate school
Add high school

Current City · Edit | San Francisco, California

Hometown · Edit |

Phone Numbers · Edit |

Address · Edit | San Francisco, CA, United States

Facebook | /snarfed.org

Social Links · Edit |

Websites · Edit | https://snarfed.org/

Websites · Edit | https://foo.bar/

Email · Edit | facebook@ryanb.org

Birthday · Edit | October 1, 1980

Gender · Edit | Male

Interested In · Edit |

Languages · Edit |

Religious Views · Edit |

Political Views · Edit |

Add a nickname, a birth name...
Married to Gina Rossman Barrett · Edit

Anniversary · Edit | October 6, 2012

Add a family member
Write about yourself
foo bar
Add a favorite quotation

Your Pages Help Settings & Privacy | Report a Problem Terms & Policies Logout (Ryan Barrett)

Back To Top